import { Octokit } from '@octokit/rest';
import { PromiseValue } from 'type-fest';
declare type OctokitType = InstanceType<typeof Octokit>;
declare type PullsListResponseItems = PromiseValue<ReturnType<InstanceType<typeof Octokit>['pulls']['list']>>['data'];
declare type IssuesListResponseItem = PromiseValue<ReturnType<InstanceType<typeof Octokit>['issues']['get']>>['data'];
export declare type ReleaseCreateResponse = PromiseValue<ReturnType<InstanceType<typeof Octokit>['repos']['createRelease']>>['data'];
import { Commit, PREdge } from './graphql-to-commits';
import { Update } from './updaters/update';
export interface OctokitAPIs {
    graphql: Function;
    request: Function;
    octokit: OctokitType;
}
interface GitHubOptions {
    defaultBranch?: string;
    token?: string;
    owner: string;
    repo: string;
    apiUrl?: string;
    proxyKey?: string;
    octokitAPIs?: OctokitAPIs;
}
export interface GitHubTag {
    name: string;
    sha: string;
    version: string;
}
export interface GitHubReleasePR {
    number: number;
    version: string;
    sha: string;
}
export interface GitHubFileContents {
    sha: string;
    content: string;
    parsedContent: string;
}
interface GitHubPR {
    branch: string;
    version: string;
    title: string;
    body: string;
    sha: string;
    updates: Update[];
    labels: string[];
}
export declare class GitHub {
    defaultBranch?: string;
    octokit: OctokitType;
    request: Function;
    graphql: Function;
    token: string | undefined;
    owner: string;
    repo: string;
    apiUrl: string;
    proxyKey?: string;
    constructor(options: GitHubOptions);
    private graphqlRequest;
    private decoratePaginateOpts;
    commitsSinceSha(sha: string | undefined, perPage?: number, labels?: boolean, path?: string | null): Promise<Commit[]>;
    private commitsWithFiles;
    private commitsWithLabels;
    pullRequestFiles(num: number, cursor: string, maxFilesChanged?: number): Promise<PREdge>;
    getTagSha(name: string): Promise<string>;
    latestTag(): Promise<GitHubTag | undefined>;
    findMergedReleasePR(labels: string[], perPage?: number): Promise<GitHubReleasePR | undefined>;
    private hasAllLabels;
    findOpenReleasePRs(labels: string[], perPage?: number): Promise<PullsListResponseItems>;
    private allTags;
    addLabels(labels: string[], pr: number): Promise<any>;
    findExistingReleaseIssue(title: string, labels: string[]): Promise<IssuesListResponseItem | undefined>;
    openPR(options: GitHubPR): Promise<number>;
    private getDefaultBranch;
    updateFiles(updates: Update[], branch: string, refName: string): Promise<void>;
    private refByBranchName;
    closePR(prNumber: number): Promise<void>;
    getFileContents(path: string): Promise<GitHubFileContents>;
    createRelease(packageName: string, version: string, sha: string, releaseNotes: string): Promise<ReleaseCreateResponse>;
    removeLabels(labels: string[], prNumber: number): Promise<void>;
    findFilesByFilename(filename: string): Promise<string[]>;
}
export {};
