import { ConventionalCommits } from './conventional-commits';
import { GitHub, GitHubTag, OctokitAPIs } from './github';
import { Commit } from './graphql-to-commits';
import { Update } from './updaters/update';
export interface BuildOptions {
    bumpMinorPreMajor?: boolean;
    defaultBranch?: string;
    label?: string;
    token?: string;
    repoUrl: string;
    packageName: string;
    releaseAs?: string;
    apiUrl: string;
    proxyKey?: string;
    snapshot?: boolean;
    lastPackageVersion?: string;
    octokitAPIs?: OctokitAPIs;
}
export interface ReleasePROptions extends BuildOptions {
    releaseType: string;
}
export interface ReleaseCandidate {
    version: string;
    previousTag?: string;
}
export declare class ReleasePR {
    static releaserName: string;
    apiUrl: string;
    defaultBranch?: string;
    labels: string[];
    gh: GitHub;
    bumpMinorPreMajor?: boolean;
    repoUrl: string;
    token: string | undefined;
    packageName: string;
    releaseAs?: string;
    proxyKey?: string;
    snapshot?: boolean;
    lastPackageVersion?: string;
    constructor(options: ReleasePROptions);
    run(): Promise<void>;
    protected _run(): Promise<void>;
    protected supportsSnapshots(): boolean;
    private closeStaleReleasePRs;
    protected defaultInitialVersion(): string;
    static lookupPackageName(gh: GitHub): Promise<string | undefined>;
    protected coerceReleaseCandidate(cc: ConventionalCommits, latestTag: GitHubTag | undefined): Promise<ReleaseCandidate>;
    protected commits(sha?: string, perPage?: number, labels?: boolean, path?: string | null): Promise<Commit[]>;
    protected gitHubInstance(octokitAPIs?: OctokitAPIs): GitHub;
    protected openPR(sha: string, changelogEntry: string, updates: Update[], version: string, includePackageName?: boolean): Promise<void>;
    protected changelogEmpty(changelogEntry: string): boolean;
}
